@@ -21,7 +21,7 @@ import re
 
 __all__ = ['space','intset']
 
-bindings_version = (0, 23)
+bindings_version = (0, 26)
 
 space = _gecode.space
 intset = _gecode.intset
@@ -63,3 +63,7 @@ def textinspector(name):
     return mk_textinspector
 
 __all__.append('textinspector')
+
+if hasattr(_gecode,'Reify'):
+    Reify = _gecode.Reify
+    __all__.append('Reify')
